:

# Use the test-case program to check if say_hello() detects if the
# file system is case-sensitive.

trap 'rm -rf $TMPDIR' 0
TMPDIR=`mktemp -d /tmp/case001-XXXXXX` || exit 1
LOWER=$TMPDIR/test-test
UPPER=$TMPDIR/TEST-TEST

touch $LOWER			# Create a file with a lowercase name
set -- `./test-case`		# Get the "ready ID N nocase" response into $*

echo $@

if [ -f $UPPER ]; then
  test "$4" = "nocase"
else
  test "$4" = ""
fi
